@@ -154,8 +154,22 @@ class Base3DProp(object):
             self._updateShadow()
         return self
 
-    def rotate(self, angle, axis=(1, 0, 0), axis_point=(0, 0, 0), rad=False):
-        """Rotate around an arbitrary `axis` passing through `axis_point`."""
+    def rotate(self, angle, axis=(1, 0, 0), point=(0, 0, 0), rad=False):
+        """Rotate around an arbitrary `axis` passing through `point`.
+
+        :Example:
+
+            .. code-block:: python
+
+                from vedo import *
+                c1 = Cube()
+                c2 = c1.clone().c('violet').alpha(0.5) # copy of c1
+                v = vector(0.2,1,0)
+                p = vector(1,0,0)  # axis passes through this point
+                c2.rotate(90, axis=v, point=p)
+                l = Line(-v+p, v+p).lw(3).c('red')
+                show(c1, l, c2, axes=1)
+        """
         if rad:
             anglerad = angle
         else:
@@ -172,7 +186,7 @@ class Base3DProp(object):
                 [2 * (bd + ac), 2 * (cd - ab), aa + dd - bb - cc],
             ]
         )
-        rv = np.dot(R, self.GetPosition() - np.array(axis_point)) + axis_point
+        rv = np.dot(R, self.GetPosition() - np.asarray(point)) + point
 
         if rad:
             angle *= 180.0 / np.pi
@@ -483,8 +497,8 @@ class Base3DProp(object):
 
         |customIndividualAxes| |customIndividualAxes.py|_
         """
-        from vedo.addons import buildAxes
-        a = buildAxes(self, **kargs)
+        from vedo.addons import Axes
+        a = Axes(self, **kargs)
         self.axes = a
         return a
 
@@ -956,16 +970,6 @@ class BaseActor(Base3DProp):
         self._mapper.SetScalarModeToUseCellData()
         return self
 
-    def removePointArray(self, name):
-        """Remove an array which was defined on points, by its name."""
-        self.inputdata().GetPointData().RemoveArray(name)
-        return self
-
-    def removeCellArray(self, name):
-        """Remove an array which was defined on cells, by its name."""
-        self.inputdata().GetCellData().RemoveArray(name)
-        return self
-
 
     def gradient(self, arrname=None, on='points', fast=False):
         """
@@ -1110,9 +1114,9 @@ class BaseActor(Base3DProp):
     def addScalarBar(self,
                      pos=(0.8,0.05),
                      title="",
-                     titleXOffset=0,
                      titleYOffset=15,
                      titleFontSize=12,
+                     size=(None,None),
                      nlabels=None,
                      c=None,
                      horizontal=False,
@@ -1126,9 +1130,9 @@ class BaseActor(Base3DProp):
         self.scalarbar = vedo.addons.addScalarBar(self,
                                                  pos,
                                                  title,
-                                                 titleXOffset,
                                                  titleYOffset,
                                                  titleFontSize,
+                                                 size,
                                                  nlabels,
                                                  c,
                                                  horizontal,
@@ -1352,12 +1356,19 @@ class BaseGrid(BaseActor):
         self._color = col
 
         if utils.isSequence(col):
-            for i, ci in enumerate(col):
-                r, g, b = colors.getColor(ci)
-                x = smin + (smax - smin) * i / (len(col) - 1)
-                ctf.AddRGBPoint(x, r, g, b)
-                #colors.printc('\tcolor at', round(x, 1),
-                #              '\tset to', colors.getColorName((r, g, b)), c='w', bold=0)
+            if utils.isSequence(col[0]) and len(col[0])==2:
+                # user passing [(value1, color1), ...]
+                for x, ci in col:
+                    r, g, b = colors.getColor(ci)
+                    ctf.AddRGBPoint(x, r, g, b)
+                    # colors.printc('color at', round(x, 1),
+                    #               'set to', colors.getColorName((r, g, b)), c='w', bold=0)
+            else:
+                # user passing [color1, color2, ..]
+                for i, ci in enumerate(col):
+                    r, g, b = colors.getColor(ci)
+                    x = smin + (smax - smin) * i / (len(col) - 1)
+                    ctf.AddRGBPoint(x, r, g, b)
         elif isinstance(col, str):
             if col in colors.colors.keys() or col in colors.color_nicks.keys():
                 r, g, b = colors.getColor(col)
