@@ -37,6 +37,7 @@ def tips():
     from vedo import colors, __version__
     msg  = " ==========================================================\n"
     msg += "| Press: i     print info about selected object            |\n"
+    msg += "|        I     print the RGB color under the mouse         |\n"
     msg += "|        <-->  use arrows to reduce/increase opacity       |\n"
     msg += "|        w/s   toggle wireframe/surface style              |\n"
     msg += "|        p/P   change point size of vertices               |\n"
@@ -44,6 +45,7 @@ def tips():
     msg += "|        x     toggle mesh visibility                      |\n"
     msg += "|        X     invoke a cutter widget tool                 |\n"
     msg += "|        1-2   change mesh color                           |\n"
+    msg += "|        3     change mesh texture                         |\n"
     msg += "|        4     use data array as colors, if present        |\n"
     msg += "|        5-6   change background color(s)                  |\n"
     msg += "|        09+-  (on keypad) or +/- to cycle axes style      |\n"
@@ -72,11 +74,11 @@ def tips():
 
     msg = " vedo " + __version__ + " "
     colors.printc(msg, invert=1, dim=1, end="")
-    try:
-        vtkVers = vtk.vtkVersion().GetVTKVersion()
-        # vtkVers = vtk.VTK_VERSION_NUMBER
-    except AttributeError:
-        vtkVers = 'unkonwn'
+    # try:
+    vtkVers = vtk.vtkVersion().GetVTKVersion()
+    # vtkVers = vtk.VTK_VERSION_NUMBER
+    # except AttributeError:
+    #     vtkVers = 'unkonwn'
     msg = "| vtk " + str(vtkVers)
     msg += " | python " + str(sys.version_info[0]) + "." + str(sys.version_info[1])
     colors.printc(msg, invert=0, dim=1)
@@ -1258,6 +1260,13 @@ _defs = ""
 #     :target: scatter2.py_
 #     :alt: scatter2.py
 
+# .. |scatter3.py| replace:: scatter3.py
+# .. _scatter3.py: https://github.com/marcomusy/vedo/tree/master/examples/pyplot/scatter3.py
+# .. |scatter3| image:: https://user-images.githubusercontent.com/32848391/72446102-2d7c0e80-37b3-11ea-8fe4-b27526af574f.png
+#     :width: 300 px
+#     :target: scatter3.py_
+#     :alt: scatter3.py
+
 # .. |customIndividualAxes.py| replace:: customIndividualAxes.py
 # .. _customIndividualAxes.py: https://github.com/marcomusy/vedo/tree/master/examples/pyplot/customIndividualAxes.py
 # .. |customIndividualAxes| image:: https://user-images.githubusercontent.com/32848391/72752870-ab7d5280-3bc3-11ea-8911-9ace00211e23.png
@@ -1342,12 +1351,11 @@ _defs = ""
 #     :alt: flag_labels.py
 
 # .. |whiskers.py| replace:: whiskers.py
-# .. _whiskers.py: https://github.com/marcomusy/vedo/tree/master/examples/pyplot/.whiskerspy
+# .. _whiskers.py: https://github.com/marcomusy/vedo/tree/master/examples/pyplot/whiskers.py
 # .. |whiskers| image:: https://user-images.githubusercontent.com/32848391/95772479-170cd000-0cbd-11eb-98c4-20c5ca342cb8.png
 #     :width: 350 px
 #     :target: whiskers.py_
 #     :alt: whiskers.py
-
 # """
 
 ######################################################################## template
