@@ -1664,8 +1664,7 @@ class Video:
     :param str name: name of the output file.
     :param int fps: set the number of frames per second.
     :param float duration: set the total `duration` of the video and recalculates `fps` accordingly.
-    :param str ffmpeg: set path to ffmpeg program.
-        Default value assumes ffmpeg command is in the path.
+    :param str ffmpeg: set path to ffmpeg program. Default value assumes ffmpeg command is in the path.
 
     |makeVideo| |makeVideo.py|_
     """
@@ -1684,6 +1683,7 @@ class Video:
         self.backend = backend
         self.fps = float(fps)
         self.command = "ffmpeg -loglevel panic -y -r"
+        self.options = "-b:v 8000k"
 
         self.frames = []
         self.tmp_dir = TemporaryDirectory()
@@ -1785,7 +1785,8 @@ class Video:
         ########################################
         if self.backend == 'ffmpeg':
             out = os.system(self.command + " " + str(self.fps)
-                            + " -i " + self.tmp_dir.name + os.sep + "%01d.png " + self.name)
+                            + " -i " + self.tmp_dir.name + os.sep
+                            + "%01d.png " + self.options + " " + self.name)
             if out:
                 colors.printc("ffmpeg returning error", c='r')
             else:
