@@ -657,6 +657,10 @@ def precision(x, p, vrange=None, delimiter='e'):
     #x= 13556.783434
     #print(round_to_n(x, 3))
     #print(precision(x, 3))
+
+    if isinstance(x, str): #do nothing
+        return x
+
     if isSequence(x):
         out = '('
         nn=len(x)-1
@@ -873,6 +877,10 @@ def printInfo(obj):
         printc(tab + "       position: ", c="g", bold=1, end="")
         printc(pos, c="g", bold=0)
 
+        if hasattr(actor, "GetScale"):
+            printc(tab + "          scale: ", c="g", bold=1, end="")
+            printc(precision(actor.GetScale(), 3), c="g", bold=0)
+
         if hasattr(actor, "polydata") and actor.N():
             printc(tab + " center of mass: ", c="g", bold=1, end="")
             cm = tuple(actor.centerOfMass())
